==> ironjacamar-parent-1.5.9.Final-source-release.zip: ironjacamar-parent-1.5.9.Final/core/tests/src/test/java/org/jboss/jca/core/connectionmanager/rar/SimpleConnectionFactory.java <==
/*
 * IronJacamar, a Java EE Connector Architecture implementation
 * Copyright 2012, Red Hat Inc, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.jca.core.connectionmanager.rar;

import java.io.Serializable;

import javax.resource.Referenceable;
import javax.resource.ResourceException;
import javax.resource.spi.ManagedConnectionFactory;

/**
 * SimpleConnectionFactory
 *
 * @version $Revision: $
 */
public interface SimpleConnectionFactory extends Serializable, Referenceable
{
   /** 
    * Get connection from factory
    *
    * @return SimpleConnection instance
    * @exception ResourceException Thrown if a connection can't be obtained
    */
   public SimpleConnection getConnection() throws ResourceException;

   /**
    * 
    * Get connection for special userID
    * 
    * @param userId connection parameter
    * @return SimpleConnection instance
    * @throws ResourceException Thrown if a connection can't be obtained
    */
   public SimpleConnection getConnection(String userId) throws ResourceException;
   
   /**
    * 
    * get MCF instance
    * 
    * @return mcf
    */
   public ManagedConnectionFactory getMCF();
}

==> ironjacamar-parent-3.0.0.Final-source-release.zip: ironjacamar-parent-3.0.0.Final/core/tests/src/test/java/org/jboss/jca/core/connectionmanager/rar/SimpleConnectionFactory.java <==
/*
 * IronJacamar, a Java EE Connector Architecture implementation
 * Copyright 2012, Red Hat Inc, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.jca.core.connectionmanager.rar;

import java.io.Serializable;

import jakarta.resource.Referenceable;
import jakarta.resource.ResourceException;
import jakarta.resource.spi.ManagedConnectionFactory;

/**
 * SimpleConnectionFactory
 *
 * @version $Revision: $
 */
public interface SimpleConnectionFactory extends Serializable, Referenceable
{
   /** 
    * Get connection from factory
    *
    * @return SimpleConnection instance
    * @exception ResourceException Thrown if a connection can't be obtained
    */
   public SimpleConnection getConnection() throws ResourceException;

   /**
    * 
    * Get connection for special userID
    * 
    * @param userId connection parameter
    * @return SimpleConnection instance
    * @throws ResourceException Thrown if a connection can't be obtained
    */
   public SimpleConnection getConnection(String userId) throws ResourceException;
   
   /**
    * 
    * get MCF instance
    * 
    * @return mcf
    */
   public ManagedConnectionFactory getMCF();
}
